function [A, Aerr, B, Berr, C, Cerr, theta0, theta0err] = XFMR_Hdep_analysis_v2(Hfmr, HWHMLW)

close all;

[fileName,pathName,filterIndex] = uigetfile('C:\Users\semori\Documents\MATLAB\XMCD XFMR\H dependence analaysis\*.dat', 'All Files');

% read in data while ignoring header
fid = fopen([pathName, '\', fileName]);

data = textscan(fid,'%f %f %f %f %f','HeaderLines',1,'Delimiter','\t','CollectOutput', 1);
data = data{1};
fclose(fid);
data = sortrows(data);
H = data(:,1); % H field
ampl = data(:,2); %XFMR amplitude
amplErr = data(:,3); %amplitude error
phase = data(:,4); %XFMR phase
phaseErr = data(:,5); %phase error

weightAmpl = 1./amplErr.^2;
weightPhase = 1./phaseErr.^2;

% Define fitting functions and parameters
mdl1 = @(b,x) 0 + b(1)*sqrt((1+(2*b(2)+b(2)^2+b(3)^2)*HWHMLW^2./(HWHMLW^2+(x-Hfmr).^2)+2*b(3)*(x-Hfmr).*HWHMLW./(HWHMLW^2+(Hfmr-x).^2)));
mdl2 = @(b,x) b(4) -180/pi*atan((b(2)*(x-Hfmr).*HWHMLW - b(3)*HWHMLW.^2)./(HWHMLW^2+(x-Hfmr).^2 + b(2)*HWHMLW^2 + b(3)*(x-Hfmr).*HWHMLW));
%mdl1 = @(b,x) cos(2*pi*beta(1)*x).*exp(-x/beta(2));
%mdl2 = @(b,x) beta(4) + beta(3)*exp(-(x/beta(2)));

% Prepare input for NLINMULTIFIT and perform fitting
x_cell = {H, H};
y_cell = {ampl, phase};
weight_cell = {weightAmpl, weightPhase};
mdl_cell = {mdl1, mdl2};

beta0 = [1e4, 0.5, -0.5, 0];
[beta,r,J,Sigma,mse,errorparam,robustw] = ...
    nlinmultifit(x_cell, y_cell, mdl_cell, beta0, 'Weights', weight_cell);

A = beta(1); 
B = beta(2);
C = beta(3);
theta0 = beta(4);

Hmdl = 30:1:170;

% Calculate model predictions and confidence intervals
[ypred1,delta1] = nlpredci(mdl1,Hmdl,beta,r,'covar',Sigma);
[ypred2,delta2] = nlpredci(mdl2,Hmdl,beta,r,'covar',Sigma);
% 
% Calculate parameter confidence intervals
ci = nlparci(beta,r,'Jacobian',J);

Aerr = (ci(1,2)-ci(1,1))/2;
Berr = (ci(2,2)-ci(2,1))/2;
Cerr = (ci(3,2)-ci(3,1))/2;
theta0err = (ci(4,2)-ci(4,1))/2;

% Plot results
h1 = figure;
hold all;
box on;
h1 = errorbar(H,ampl,amplErr,'bo', 'MarkerSize', 12);
xlabel('H (Oe)');
ylabel('amplitude (a.u.)');
h1 = plot(Hmdl,ypred1,'Color','blue');
% 		plot(x1,ypred1+delta1,'Color','blue','LineStyle',':');
% 		plot(x1,ypred1-delta1,'Color','blue','LineStyle',':');
title(strvcat(['H_{fmr} = ', num2str(Hfmr, '%.1f'), ' Oe, \Delta H_{hwhm} = ', num2str(HWHMLW, '%.1f'), ' Oe'], ...
    ['A = ', num2str(A, '%.3e'), '\pm' num2str(Aerr, '%.3e')],...
    ['b_{STT}/b_{RF} = ', num2str(B, '%.3f'), '\pm' num2str(Berr, '%.3f')], ...
    ['b_{FLT}/b_{RF} = ', num2str(C, '%.3f'), '\pm' num2str(Cerr, '%.3f')]));
saveas(h1, [pathName, '\', fileName, '-Hfmr', num2str(Hfmr,'%.1f'),'Oe-LW', num2str(HWHMLW,'%.1f'),'Oe-AmplVsH.jpg']); 

h2 = figure;
hold on; 
h2 = errorbar(H,phase,phaseErr, 'o', 'Color',[0 0.5 0],'MarkerSize', 12);
h2 = plot(Hmdl,ypred2,'Color',[0 0.5 0]);
% 		plot(x2,ypred2+delta2,'Color',[0 0.5 0],'LineStyle',':');
% 		plot(x2,ypred2-delta2,'Color',[0 0.5 0],'LineStyle',':');
title(strvcat(['H_{fmr} = ', num2str(Hfmr, '%.1f'), ' Oe, \Delta H_{hwhm} = ', num2str(HWHMLW, '%.1f'), ' Oe'], ...
    ['\theta_0 = ', num2str(theta0, '%.2f'), '\pm' num2str(theta0err, '%.2f'), ' deg.'],...
    ['b_{STT}/b_{RF} = ', num2str(B, '%.3f'), '\pm' num2str(Berr, '%.3f')], ...
    ['b_{FLT}/b_{RF} = ', num2str(C, '%.3f'), '\pm' num2str(Cerr, '%.3f')]));
saveas(h2, [pathName, '\', fileName, '-Hfmr', num2str(Hfmr,'%.1f'),'Oe-LW', num2str(HWHMLW,'%.1f'),'Oe-PhaseVsH.jpg']); 